<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet exclude-result-prefixes="tei mets html map"
    xmlns:map="urn:uuid:88a07861-a998-4c1b-bc3f-cf169a4aab52"
    xmlns:html="http://www.w3.org/1999/xhtml"
    xmlns:mets="http://www.loc.gov/METS/"
    xmlns:tei="http://www.tei-c.org/ns/1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0">
    
    <xsl:import href="default_sz2.xsl"/>
    
    <xsl:output method="html" encoding="utf-8" indent="yes"/>
    
    <xsl:variable name="metsFile" select="document('../mets.xml')"/>
    <xsl:variable name="fileId"   select="/*/@xml:id"/>
    <xsl:variable name="metsId"   select="$metsFile//mets:div[mets:fptr[@FILEID = $fileId]]/@ID"/>
    <xsl:variable name="currentFile" select="document('../daten/sz2/register/listBibl_s2.xml')"/>
    <xsl:variable name="glossFile" select="document('../daten/sz2/register/listGloss_s2.xml')"/>
    <xsl:variable name="cod_guelf_28_blank_Data" select="document('../daten/sz2/cod_guelf_28_blank.xml')//tei:text"/>
    <xsl:variable name="cod_guelf_286a_blank_Data" select="document('../daten/sz2/cod_guelf_286a_blank.xml')//tei:text"/>
    <xsl:variable name="cod_guelf_211_1_extrav_Data" select="document('../daten/sz2/cod_guelf_211_1_extrav.xml')//tei:text"/>
    
    <map:map>
        <map:entry key="01" value="Januar"/>
        <map:entry key="02" value="Februar"/>
        <map:entry key="03" value="März"/>
        <map:entry key="04" value="April"/>
        <map:entry key="05" value="Mai"/>
        <map:entry key="06" value="Juni"/>
        <map:entry key="07" value="Juli"/>
        <map:entry key="08" value="August"/>
        <map:entry key="09" value="September"/>
        <map:entry key="10" value="Oktober"/>
        <map:entry key="11" value="November"/>
        <map:entry key="12" value="Dezember"/>
    </map:map>
    
    <xsl:template match="/tei:TEI">
        <html>
            <head>
                <meta charset="utf-8"/>
                <meta http-equiv="X-UA-Compatible" content="IE=edge"/>
                <meta name="viewport" content="width=device-width, initial-scale=1"/>
                <!--<xsl:apply-templates mode="header"/>-->
                <link rel="schema.DC" href="http://purl.org/dc/elements/1.1/"/>
                <link rel="schema.DCTERMS" href="http://purl.org/dc/terms/"/>
                <!-- Assets -->
                <link rel="schema.DC" href="http://purl.org/dc/elements/1.1/"/>
                <link rel="schema.DCTERMS" href="http://purl.org/dc/terms/"/>
                <!-- Assets -->
                <link rel="stylesheet" href="/assets/selbstzeugnisse/css/reset.css" media="screen"/>
                <link rel="stylesheet" href="/assets/font-awesome/css/font-awesome.min.css" media="screen"/>
                <link rel="stylesheet" href="/assets/selbstzeugnisse/css/selbstzeugnisse2.css" media="screen"/>
                <link rel="stylesheet" href="/assets/selbstzeugnisse/css/print.css" media="print"/>
                <script type="text/javascript" src="/assets/jquery/jquery-3.4.1.min.js"></script>
                <script type="text/javascript" src="/assets/jquery-zoom/jquery.zoom.min.js"></script>
                <script type="text/javascript" src="/assets/selbstzeugnisse/js/selbstzeugnisse2.js"></script>
                <noscript>
                    <style type="text/css">.js-toggle { display: inherit; }</style>
                </noscript>
                <title>Literaturregister</title>
            </head>
            <body>
                <div class="banner">
                    <img src="/assets/selbstzeugnisse/images/banner_logo.png" class="brand"/>
                    <div class="banner-logo">
                        <img src="/assets/selbstzeugnisse/images/banner_logo_hab.png"/>
                        <form method="GET" action="/suche">
                            <input type="text" name="query" placeholder="&#x1F50E;"/>
                        </form>
                    </div>
                    <div class="banner-slogan">
                        <h1>Selbstzeugnisse <small>der Frühen Neuzeit</small></h1>
                        <h2>in der Herzog August Bibliothek</h2>
<!--                        <h3>Digitale Edition des Diariums von Herzog August dem Jüngeren · Digitale Edition der Diarien Herzog Ludwig Rudolphs und Herzogin Christiane Luises von Braunschweig-Wolfenbüttel · Selbstzeugnis-Repertorium · Forschungsportal</h3>-->
                    </div>
                </div>
                <div class="content">
                    <xsl:apply-templates/>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:template match="tei:teiHeader"/>
    
    <xsl:template match="tei:listBibl">
        <h1>Register der erwähnten oder zitierten Literaturwerke und Theaterstücke</h1>
        <h2 id="Literatur">Literaturwerke</h2>
        <xsl:for-each select="$currentFile//tei:bibl">
            <xsl:sort select="."/>
            <xsl:apply-templates select="."/>
        </xsl:for-each>
        <h2 id="Dramen">Dramen</h2>
        <h3 id="Komödien">Komödien</h3>
        <xsl:for-each select="$glossFile//tei:item[starts-with(@xml:id,'komoedie')]">
            <xsl:sort select="@xml:id"/>
            <xsl:apply-templates select="."/>
        </xsl:for-each>        
        <h3 id="Tragödien">Tragödien</h3>
        <xsl:for-each select="$glossFile//tei:item[starts-with(@xml:id,'tragoedie')]">
            <xsl:sort select="@xml:id"/>
            <xsl:apply-templates select="."/>
        </xsl:for-each>
        <h2 id="Opern">Opern</h2>
        <xsl:for-each select="$glossFile//tei:item[starts-with(@xml:id,'oper')]">
            <xsl:sort select="@xml:id"/>
            <xsl:apply-templates select="."/>
        </xsl:for-each>
    </xsl:template>
    
    <xsl:template match="tei:text/tei:body">
        <div class="navigation">
            <xsl:call-template name="navigation"/>
        </div>
        <div class="mainpage register">
            <xsl:apply-templates select="tei:listBibl"/>
        </div>
        <div class="infopanel">
            <!--<div class="screen-only controls">
                <ul>
                    <li><a class="fa fa-print" href="javascript:print()"> Drucken</a></li>
                </ul>
            </div>-->
            <div class="facet">
                <h1>Schnellauswahl</h1>
                <ul>
                    <li>
                        <a href="#Literatur">Literaturwerke</a>
                    </li>
                    <li>
                        <a href="#Dramen">Dramen</a>
                        <ul>
                            <li>
                                <a href="#Komödien">Komödien</a>
                            </li>                    
                            <li>
                                <a href="#Tragödien">Tragödien</a>
                            </li>
                        </ul>
                    </li>                    
                    <li>
                        <a href="#Opern">Opern</a>
                    </li>
                </ul>
            </div>
        </div>
    </xsl:template>
    
    <xsl:template match="tei:bibl">
        <dl>
            <dt>
                <xsl:value-of select="./text()"/> 
            </dt>
            <dd>
                <xsl:apply-templates select="tei:ptr"/>
            </dd>
            <table>
                <tbody>
                    <xsl:if test="$cod_guelf_28_blank_Data//tei:rs[@type='bibl'][not(contains(@ref,' '))][substring-after(@ref,'#')=current()/@xml:id]">
                        <tr>
                            <td><h4>Cod. Guelf. 28 Blank.:</h4></td>
                            <td>
                                <xsl:for-each select="$cod_guelf_28_blank_Data//tei:rs[@type='bibl'][not(contains(@ref,' '))][substring-after(@ref,'#')=current()/@xml:id]">
                                    <a href="cod_guelf_28_blank{concat(@ref,'_',preceding::tei:pb[1]/@n)}"><xsl:value-of select="preceding::tei:pb[1]/@n"/></a>
                                    <xsl:if test="position()!=last()">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>
                    <xsl:if test="$cod_guelf_211_1_extrav_Data//tei:rs[@type='bibl'][not(contains(@ref,' '))][substring-after(@ref,'#')=current()/@xml:id]">
                        <tr>
                            <td><h4>Cod. Guelf. 211,1 Extrav.:</h4></td>
                            <td>
                                <xsl:for-each select="$cod_guelf_211_1_extrav_Data//tei:rs[@type='bibl'][not(contains(@ref,' '))][substring-after(@ref,'#')=current()/@xml:id]">
                                    <a href="cod_guelf_211_1_extrav{concat(@ref,'_',preceding::tei:pb[1]/@n)}"><xsl:value-of select="preceding::tei:pb[1]/@n"/></a>
                                    <xsl:if test="position()!=last()">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>
                    <xsl:if test="$cod_guelf_286a_blank_Data//tei:rs[@type='bibl'][not(contains(@ref,' '))][substring-after(@ref,'#')=current()/@xml:id]">
                        <tr>
                            <td><h4>Cod. Guelf. 286a Blank.:</h4></td>
                            <td>
                                <xsl:for-each select="$cod_guelf_286a_blank_Data//tei:rs[@type='bibl'][not(contains(@ref,' '))][substring-after(@ref,'#')=current()/@xml:id]">
                                    <a href="cod_guelf_286a_blank{concat(@ref,'_',preceding::tei:pb[1]/@n)}"><xsl:value-of select="preceding::tei:pb[1]/@n"/></a>
                                    <xsl:if test="position()!=last()">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>                
                </tbody>
            </table>            
        </dl>
    </xsl:template>
    
    <xsl:template match="tei:item">
        <dl>
            <xsl:apply-templates select="tei:label"/>
        </dl>
    </xsl:template>
    
    <xsl:template match="tei:label">
        <dt id="{parent::tei:item/@xml:id}">
            <xsl:value-of select="substring-after(.,' ')"/>
        </dt>
        <dd>
            <xsl:apply-templates select="parent::tei:item/tei:list"/>
        </dd>
        <table>
            <tbody>
                <xsl:if test="$cod_guelf_28_blank_Data//tei:term[not(contains(@ref,' '))][substring-after(@ref,'#')=current()/parent::tei:item/@xml:id]">
                    <tr>
                        <td><h4>Cod. Guelf. 28 Blank.:</h4></td>
                        <td>
                            <xsl:for-each select="$cod_guelf_28_blank_Data//tei:term[not(contains(@ref,' '))][substring-after(@ref,'#')=current()/parent::tei:item/@xml:id]">
                                <a href="cod_guelf_28_blank{concat(@ref,'_',preceding::tei:pb[1]/@n)}"><xsl:value-of select="preceding::tei:pb[1]/@n"/></a>
                                <xsl:if test="position()!=last()">
                                    <xsl:text>, </xsl:text>
                                </xsl:if>
                            </xsl:for-each>
                        </td>
                    </tr>
                </xsl:if>
                <xsl:if test="$cod_guelf_211_1_extrav_Data//tei:term[not(contains(@ref,' '))][substring-after(@ref,'#')=current()/parent::tei:item/@xml:id]">
                    <tr>
                        <td><h4>Cod. Guelf. 211,1 Extrav.:</h4></td>
                        <td>
                            <xsl:for-each select="$cod_guelf_211_1_extrav_Data//tei:term[not(contains(@ref,' '))][substring-after(@ref,'#')=current()/parent::tei:item/@xml:id]">
                                <a href="cod_guelf_211_1_extrav{concat(@ref,'_',preceding::tei:pb[1]/@n)}"><xsl:value-of select="preceding::tei:pb[1]/@n"/></a>
                                <xsl:if test="position()!=last()">
                                    <xsl:text>, </xsl:text>
                                </xsl:if>
                            </xsl:for-each>
                        </td>
                    </tr>
                </xsl:if>
                <xsl:if test="$cod_guelf_286a_blank_Data//tei:term[not(contains(@ref,' '))][substring-after(@ref,'#')=current()/parent::tei:item/@xml:id]">
                    <tr>
                        <td><h4>Cod. Guelf. 286a Blank.:</h4></td>
                        <td>
                            <xsl:for-each select="$cod_guelf_286a_blank_Data//tei:term[not(contains(@ref,' '))][substring-after(@ref,'#')=current()/parent::tei:item/@xml:id]">
                                <a href="cod_guelf_286a_blank{concat(@ref,'_',preceding::tei:pb[1]/@n)}"><xsl:value-of select="preceding::tei:pb[1]/@n"/></a>
                                <xsl:if test="position()!=last()">
                                    <xsl:text>, </xsl:text>
                                </xsl:if>
                            </xsl:for-each>
                        </td>
                    </tr>
                </xsl:if>                
            </tbody>
        </table> 
    </xsl:template>
    
    <xsl:template match="tei:list[not(@type='gloss')]">
        <xsl:value-of select="tei:item"/>
    </xsl:template>
    
    <xsl:template match="tei:ptr">
        <xsl:choose>
            <xsl:when test="@type='opac'">
                Eintrag im <a target="_blank" href="http://opac.lbs-braunschweig.gbv.de/DB=2/XMLPRS=N/PPN?PPN={@cRef}">HAB-OPAC</a>.
            </xsl:when>
            <xsl:when test="@type='gvk'">
                Eintrag im <a target="_blank" href="https://kxp.k10plus.de/DB=2.1/PPNSET?PPN={@cRef}">GVK</a>.
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
</xsl:stylesheet>